@@ -24,9 +24,7 @@
 #' @param object2 The other `lcModel` to compare with.
 #' @param name The name(s) of the external metric(s) to compute. If no names are given, the names specified in the `latrend.externalMetric` option (none by default) are used.
 #' @return A named `numeric` vector containing the computed model metrics.
-#' @details
-#' List of currently supported external metrics:
-#'
+#' @section Supported external metrics:
 #' | **Metric name** | **Description** | **Function / Reference** |
 #' | --- | :-------- | :--- |
 #' | `adjustedRand` | [Adjusted Rand index](https://en.wikipedia.org/wiki/Rand_index). Based on the Rand index, but adjusted for agreements occurring by chance. A score of 1 indicates a perfect agreement, whereas a score of 0 indicates an agreement no better than chance. | [mclustcomp::mclustcomp()], \insertCite{hubert1985comparing}{latrend} |
@@ -141,7 +139,9 @@ extMetricsEnv$F1 = function(m1, m2) {
 }
 
 extMetricsEnv$FolkesMallows = function(m1, m2) {
+  .loadOptionalPackage('clusterCrit')
   assert_that(has_same_ids(m1, m2))
+
   clusterCrit::extCriteria(
     trajectoryAssignments(m1) %>% as.integer,
     trajectoryAssignments(m2) %>% as.integer,
@@ -150,7 +150,9 @@ extMetricsEnv$FolkesMallows = function(m1, m2) {
 }
 
 extMetricsEnv$Hubert = function(m1, m2) {
+  .loadOptionalPackage('clusterCrit')
   assert_that(has_same_ids(m1, m2))
+
   clusterCrit::extCriteria(
     trajectoryAssignments(m1) %>% as.integer,
     trajectoryAssignments(m2) %>% as.integer,
@@ -159,7 +161,9 @@ extMetricsEnv$Hubert = function(m1, m2) {
 }
 
 extMetricsEnv$Jaccard = function(m1, m2) {
+  .loadOptionalPackage('clusterCrit')
   assert_that(has_same_ids(m1, m2))
+
   clusterCrit::extCriteria(
     trajectoryAssignments(m1) %>% as.integer,
     trajectoryAssignments(m2) %>% as.integer,
@@ -177,7 +181,9 @@ extMetricsEnv$jointEntropy = function(m1, m2) {
 }
 
 extMetricsEnv$Kulczynski = function(m1, m2) {
+  .loadOptionalPackage('clusterCrit')
   assert_that(has_same_ids(m1, m2))
+
   clusterCrit::extCriteria(
     trajectoryAssignments(m1) %>% as.integer,
     trajectoryAssignments(m2) %>% as.integer,
@@ -195,7 +201,9 @@ extMetricsEnv$MaximumMatch = function(m1, m2) {
 }
 
 extMetricsEnv$McNemar = function(m1, m2) {
+  .loadOptionalPackage('clusterCrit')
   assert_that(has_same_ids(m1, m2))
+
   clusterCrit::extCriteria(
     trajectoryAssignments(m1) %>% as.integer,
     trajectoryAssignments(m2) %>% as.integer,
@@ -272,7 +280,9 @@ extMetricsEnv$PD = function(m1, m2) {
 
 
 extMetricsEnv$Phi = function(m1, m2) {
+  .loadOptionalPackage('clusterCrit')
   assert_that(has_same_ids(m1, m2))
+
   clusterCrit::extCriteria(
     trajectoryAssignments(m1) %>% as.integer,
     trajectoryAssignments(m2) %>% as.integer,
@@ -281,7 +291,9 @@ extMetricsEnv$Phi = function(m1, m2) {
 }
 
 extMetricsEnv$precision = function(m1, m2) {
+  .loadOptionalPackage('clusterCrit')
   assert_that(has_same_ids(m1, m2))
+
   clusterCrit::extCriteria(
     trajectoryAssignments(m1) %>% as.integer,
     trajectoryAssignments(m2) %>% as.integer,
@@ -290,7 +302,9 @@ extMetricsEnv$precision = function(m1, m2) {
 }
 
 extMetricsEnv$Rand = function(m1, m2) {
+  .loadOptionalPackage('clusterCrit')
   assert_that(has_same_ids(m1, m2))
+
   clusterCrit::extCriteria(
     trajectoryAssignments(m1) %>% as.integer,
     trajectoryAssignments(m2) %>% as.integer,
@@ -299,7 +313,9 @@ extMetricsEnv$Rand = function(m1, m2) {
 }
 
 extMetricsEnv$recall = function(m1, m2) {
+  .loadOptionalPackage('clusterCrit')
   assert_that(has_same_ids(m1, m2))
+
   clusterCrit::extCriteria(
     trajectoryAssignments(m1) %>% as.integer,
     trajectoryAssignments(m2) %>% as.integer,
@@ -308,7 +324,9 @@ extMetricsEnv$recall = function(m1, m2) {
 }
 
 extMetricsEnv$RogersTanimoto = function(m1, m2) {
+  .loadOptionalPackage('clusterCrit')
   assert_that(has_same_ids(m1, m2))
+
   clusterCrit::extCriteria(
     trajectoryAssignments(m1) %>% as.integer,
     trajectoryAssignments(m2) %>% as.integer,
@@ -317,7 +335,9 @@ extMetricsEnv$RogersTanimoto = function(m1, m2) {
 }
 
 extMetricsEnv$RusselRao = function(m1, m2) {
+  .loadOptionalPackage('clusterCrit')
   assert_that(has_same_ids(m1, m2))
+
   clusterCrit::extCriteria(
     trajectoryAssignments(m1) %>% as.integer,
     trajectoryAssignments(m2) %>% as.integer,
@@ -352,7 +372,9 @@ extMetricsEnv$splitJoin.ref = function(m1, m2) {
 }
 
 extMetricsEnv$SokalSneath1 = function(m1, m2) {
+  .loadOptionalPackage('clusterCrit')
   assert_that(has_same_ids(m1, m2))
+
   clusterCrit::extCriteria(
     trajectoryAssignments(m1) %>% as.integer,
     trajectoryAssignments(m2) %>% as.integer,
@@ -361,7 +383,9 @@ extMetricsEnv$SokalSneath1 = function(m1, m2) {
 }
 
 extMetricsEnv$SokalSneath2 = function(m1, m2) {
+  .loadOptionalPackage('clusterCrit')
   assert_that(has_same_ids(m1, m2))
+
   clusterCrit::extCriteria(
     trajectoryAssignments(m1) %>% as.integer,
     trajectoryAssignments(m2) %>% as.integer,
