@@ -1,27 +1,27 @@
 context('lcMethods')
 
 test_that('as.lcMethods non-list', {
-  out = as.lcMethods(lcMethodTestKML())
+  out = as.lcMethods(mTest)
   expect_is(out, 'lcMethods')
   expect_length(out, 1)
 })
 
 test_that('as.lcMethods', {
-  methods = list(lcMethodTestLMKM(), lcMethodTestKML())
+  methods = list(mTest, mRandom)
   out = as.lcMethods(methods)
   expect_is(out, 'lcMethods')
   expect_length(out, 2)
 })
 
 test_that('as.data.frame single-row', {
-  methods = as.lcMethods(lcMethodTestKML())
+  methods = as.lcMethods(mTest)
   df = as.data.frame(methods)
   expect_is(df, 'data.frame')
   expect_equal(nrow(df), 1)
 })
 
 test_that('as.data.frame multi-row', {
-  methods = as.lcMethods(list(lcMethodTestKML(nClusters = 2), lcMethodTestKML(nClusters = 3)))
+  methods = as.lcMethods(list(mTest2, mTest3))
   df = as.data.frame(methods)
   expect_is(df, 'data.frame')
   expect_equal(nrow(df), 2)
@@ -29,45 +29,44 @@ test_that('as.data.frame multi-row', {
 })
 
 test_that('as.data.frame multi-row different classes', {
-  methods = as.lcMethods(list(lcMethodTestLMKM(), lcMethodTestKML()))
+  methods = as.lcMethods(list(mTest, mRandom))
   df = as.data.frame(methods)
   expect_is(df, 'data.frame')
   expect_equal(nrow(df), 2)
 })
 
 test_that('vector argument', {
-  methods = lcMethods(lcMethodTestKML(), nClusters = 1:3)
+  methods = lcMethods(lcMethodTestLMKM(), nClusters = 1:3)
   expect_is(methods, 'list')
   expect_length(methods, 3)
 })
 
 test_that('vector variable argument', {
   nclus = 1:3
-  methods = lcMethods(lcMethodTestKML(), nClusters = nclus)
+  methods = lcMethods(lcMethodTestLMKM(), nClusters = nclus)
   expect_is(methods, 'list')
   expect_length(methods, 3)
 })
 
 test_that('error argument', {
-  expect_error(lcMethods(lcMethodTestKML(), fail = stop('no')), 'fail')
+  expect_error(lcMethods(lcMethodTestLMKM(), fail = stop('no')), 'fail')
 })
 
 test_that('default', {
-  methods = lcMethods(lcMethodTestKML())
+  methods = lcMethods(lcMethodTestLMKM())
   expect_is(methods, 'list')
   expect_length(methods, 1)
 })
 
 test_that('var', {
-  kml = lcMethodTestKML()
-  methods = lcMethods(kml)
+  methods = lcMethods(mTest)
   expect_is(methods, 'list')
   expect_length(methods, 1)
 })
 
 
 test_that('scalar argument', {
-  methods = lcMethods(lcMethodTestKML(), nClusters = 2)
+  methods = lcMethods(mTest, nClusters = 2)
   expect_is(methods, 'list')
   expect_length(methods, 1)
   expect_equal(methods[[1]]$nClusters, 2)
@@ -75,7 +74,7 @@ test_that('scalar argument', {
 
 
 test_that('char argument', {
-  methods = lcMethods(lcMethodTestKML(), nClusters = 2, test = 'a')
+  methods = lcMethods(mTest, nClusters = 2, test = 'a')
   expect_is(methods, 'list')
   expect_length(methods, 1)
   expect_equal(methods[[1]]$nClusters, 2)
@@ -84,8 +83,7 @@ test_that('char argument', {
 
 
 test_that('var with vector argument', {
-  kml = lcMethodTestKML()
-  methods = lcMethods(kml, nClusters = 1:3)
+  methods = lcMethods(mTest, nClusters = 1:3)
   expect_is(methods, 'list')
   expect_length(methods, 3)
 })
@@ -93,7 +91,7 @@ test_that('var with vector argument', {
 test_that('.() argument', {
   a = 1
   b = 2
-  methods = lcMethods(lcMethodTestKML(), nClusters = .(a,b))
+  methods = lcMethods(mTest, nClusters = .(a,b))
   expect_is(methods, 'list')
   expect_length(methods, 2)
 
@@ -105,7 +103,7 @@ test_that('.() argument', {
 test_that('cartesian', {
   a = 1
   b = 2
-  methods = lcMethods(lcMethodTestKML(), maxIt = 10, seed = .(a, b), nClusters = 1:3)
+  methods = lcMethods(mTest, maxIt = 10, seed = .(a, b), nClusters = 1:3)
   expect_is(methods, 'list')
   expect_length(methods, 1 * 2 * 3)
 
@@ -116,7 +114,7 @@ test_that('cartesian', {
 })
 
 test_that('do.call', {
-  m = lcMethodTestKML() %>% evaluate()
+  m = evaluate(mTest)
   methods = do.call(lcMethods, list(m, maxIt = 10, seed = 1:3, nClusters = 2))
   expect_is(methods, 'list')
   expect_length(methods, 1 * 3 * 1)
@@ -124,6 +122,6 @@ test_that('do.call', {
 
 test_that('unnamed argument', {
   expect_error({
-    lcMethods(lcMethodTestKML(), 2)
+    lcMethods(mTest, 2)
   })
 })
