@@ -2,11 +2,13 @@ context('metrics')
 skip_if_not_installed('mclust')
 skip_if_not_installed('psych')
 skip_if_not_installed('igraph')
+skip_if_not_installed('clusterCrit')
 rngReset()
 
 internalMetrics = getInternalMetricNames() %>%
   setdiff(c('deviance', 'SED.fit', 'ED.fit'))
 
+
 test_that('two clusters', {
   for (name in internalMetrics) {
     value = metric(testModel2, name = name)
@@ -15,6 +17,7 @@ test_that('two clusters', {
   }
 })
 
+
 test_that('single cluster', {
   for (name in internalMetrics) {
     value = metric(testModel1, name = name)
@@ -23,16 +26,19 @@ test_that('single cluster', {
   }
 })
 
+
 test_that('error on empty name', {
   expect_error(metric(testModel1, name = NULL))
 })
 
+
 test_that('default names', {
   # if this test fails then the documentation needs to be updated
   out = metric(testModel2)
   expect_named(out, c('WRSS', 'APPA.mean'))
 })
 
+
 test_that('MAE', {
   out = metric(testModel2, 'MAE')
 
@@ -40,6 +46,7 @@ test_that('MAE', {
   expect_equivalent(out, mean(abs(residuals(testModel2, clusters = trajectoryAssignments(testModel2)))))
 })
 
+
 test_that('MSE', {
   out = metric(testModel2, 'MSE')
 
@@ -47,6 +54,50 @@ test_that('MSE', {
   expect_equivalent(out, mean(residuals(testModel2, clusters = trajectoryAssignments(testModel2))^2))
 })
 
+
+test_that('ASW', {
+  out = metric(testModel2, 'ASW')
+
+  expect_gte(out, -1)
+  expect_lte(out, 1)
+
+  # compare result to clusterCrit
+  skip_if_not_installed('clusterCrit')
+  part = as.integer(trajectoryAssignments(testModel2))
+  tsmat = tsmatrix(
+    data = model.data(testModel2),
+    response = responseVariable(testModel2),
+    id = idVariable(testModel2),
+    time = timeVariable(testModel2),
+    fill = NA_real_
+  )
+  sil = clusterCrit::intCriteria(tsmat, part, crit = 'Silhouette')$silhouette
+
+  expect_equal(out, sil, tolerance = .01, check.attributes = FALSE)
+})
+
+
+test_that('Dunn', {
+  out = metric(testModel2, 'Dunn')
+
+  expect_gte(out, 0)
+
+  # compare result to clusterCrit
+  skip_if_not_installed('clusterCrit')
+  part = as.integer(trajectoryAssignments(testModel2))
+  tsmat = tsmatrix(
+    data = model.data(testModel2),
+    response = responseVariable(testModel2),
+    id = idVariable(testModel2),
+    time = timeVariable(testModel2),
+    fill = NA_real_
+  )
+  di = clusterCrit::intCriteria(tsmat, part, crit = 'Dunn')$dunn
+
+  expect_equal(out, di, tolerance = .001, check.attributes = FALSE)
+})
+
+
 test_that('WMAE', {
   wmae = metric(testModel2, 'WMAE')
   mae = metric(testModel2, 'MAE')
@@ -60,23 +111,28 @@ test_that('WMAE', {
   expect_gte(wmaeFuzzy, maeFuzzy)
 })
 
+
 test_that('Mahalanobis', {
   expect_true('Mahalanobis' %in% getInternalMetricNames())
 })
 
+
 test_that('missing metric', {
   expect_warning(met <- metric(testModel2, '.MISSING'))
   expect_true(is.na(met))
 })
 
+
 test_that('metric definition', {
   expect_true(is.function(getInternalMetricDefinition('MAE')))
 })
 
+
 test_that('missing metric definition', {
   expect_error(getInternalMetricDefinition('.MISSING'))
 })
 
+
 test_that('define metric', {
   defineInternalMetric('.NEW', force)
   expect_warning(defineInternalMetric('.NEW', force))
@@ -84,6 +140,7 @@ test_that('define metric', {
   expect_equal(getInternalMetricDefinition('.NEW'), force)
 })
 
+
 test_that('plot single model', {
   expect_is(
     plotMetric(testModel, 'WMAE'),
@@ -91,6 +148,7 @@ test_that('plot single model', {
   )
 })
 
+
 test_that('plot single model, multiple metrics', {
   expect_is(
     plotMetric(testModel, c('WMAE', 'RMSE')),
